@@ -3,8 +3,9 @@ package HTTP::Body;
 use strict;
 
 use Carp       qw[ ];
+use List::Util qw[ first ];
 
-our $VERSION = '0.03';
+our $VERSION = '0.2';
 
 our $TYPES = {
     'application/octet-stream'          => 'HTTP::Body::OctetStream',
@@ -65,13 +66,7 @@ sub new {
         Carp::croak( $class, '->new( $content_type, $content_length )' );
     }
 
-    my $type;
-    foreach my $supported ( keys %{$TYPES} ) {
-        if ( index( lc($content_type), $supported ) >= 0 ) {
-            $type = $supported;
-        }
-    }
-
+    my $type = first { index( lc($content_type), $_ ) >= 0 } keys %{$TYPES};
     my $body = $TYPES->{ $type || 'application/octet-stream' };
 
     eval "require $body";
@@ -98,7 +93,7 @@ sub new {
 
 =item add
 
-Add string to internal buffer. Will call spin unless done. returns
+Add string to itnernal buffer. Will call spin unless done. returns
 length before adding self.
 
 =cut
@@ -256,10 +251,6 @@ sub upload {
 
 =back
 
-=head1 BUGS
-
-Chunked requests are currently not supported.
-
 =head1 AUTHOR
 
 Christian Hansen, C<ch@ngmedia.com>
